gchecky.model.item_shipping_information_t

Package gchecky :: Module model :: Class item_shipping_information_t |
[hide private]
[frames] | no frames]

# Class item_shipping_information_t

source code

    object --+
             |
     gxml.Node --+
                 |
                item_shipping_information_t

Nested Classes | [hide private]
Inherited from `gxml.Node`: `__metaclass__`

Instance Methods | [hide private]
Inherited from `gxml.Node`: `__eq__`, `__init__`, `__neq__`, `read`, `write` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Methods | [hide private]
Inherited from `gxml.Node`: `fields`, `set_fields`

Static Methods | [hide private]
Inherited from `gxml.Node`: `__new__`

Class Variables | [hide private]
| item_id = `Node:PATH(item-id):REQ:{ item_id_t }`
| tracking_data_list = `List:PATH(tracking-data-list):RE`...``
| _fields = ``{``'``item_id``'``:` Node:PATH(item-id):REQ:{ item_id_t }`,` `'``t``...`` list of meta-Fields of this class.

Properties | [hide private]
Inherited from `object`: `__class__`

Class Variable Details | [hide private]

  ### tracking_data_list Value:
      List:PATH(tracking-data-list):REQ:[
          Node:PATH(tracking-data):REQ:{ tracking_data_t }
      ]

  ### _fields list of meta-Fields of this class. Value:
      {'item_id': Node:PATH(item-id):REQ:{ item_id_t },
       'tracking_data_list': List:PATH(tracking-data-list):REQ:[
          Node:PATH(tracking-data):REQ:{ tracking_data_t }
      ]}